#!/usr/bin/env python3
# -*- coding: utf-8 -*-

'''这是 "nester.py" 模块，提供了一个名为 print_lol() 的函数，
函数的作用是打印列表，其中有可能包含(也可能不包含)嵌套列表。'''

def print_lol(the_list, level=0):
    '''这个函数取一个位置参数，名为 "the_list"，这可以是任何 python
    列表(也可以是包含嵌套列表的列表)。所指定的列表中的每个数据会(递归的)
    输出到屏幕上，每个数据项各占一行。
    第二个参数 "level" 用来标记当前列表的嵌套深度，会输入对应的缩进符。'''
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            for x in range(level):
                print("\t", end = '')
            print(each_item)



from distutils.core import setup

setup(
    name = 'nesterkang',
    version = '1.1.0',
    py_modules = ['nesterkang'],
    author = 'kangchenyun',
    author_email = 'kangchenyun@gmail.com',
    url = 'http://kangchenyun.github.io',
    description = 'A simple printer of nested lists',
    )
